=== modified file 'docs/alter_schema.rst'
--- docs/alter_schema.rst	2011-01-07 03:04:54 +0000
+++ docs/alter_schema.rst	2011-02-15 22:03:42 +0000
@@ -3,7 +3,9 @@
 
 ALTER SCHEMA changes the definition of a schema.
 
-You must own the schema to use ALTER SCHEMA. To rename a schema you must also have the CREATE privilege for the database. To alter the owner, you must also be a direct or indirect member of the new owning role, and you must have the CREATE privilege for the database.::
+You must own the schema to use ALTER SCHEMA. To rename a schema you must also have the CREATE privilege for the database. To alter the owner, you must also be a direct or indirect member of the new owning role, and you must have the CREATE privilege for the database:
+
+.. code-block:: mysql
 
 	ALTER SCHEMA name RENAME TO new_name
 	ALTER SCHEMA name OWNER TO new_owner
@@ -21,7 +23,6 @@
     The new owner of the schema. 
 
 
-See Also:
+.. seealso::
 
-* CREATE SCHEMA
-* DROP SCHEMA
\ No newline at end of file
+   :doc:`create_schema` and :doc:`drop_schema`

=== modified file 'docs/clients/drizzledump.rst'
--- docs/clients/drizzledump.rst	2011-02-13 20:50:37 +0000
+++ docs/clients/drizzledump.rst	2011-02-15 22:03:42 +0000
@@ -87,7 +87,9 @@
 
 .. option:: --skip-extended-insert
 
-Dump every row on an individual line.  For example::
+Dump every row on an individual line.  For example:
+
+.. code-block:: mysql
 
 	INSERT INTO `t1` VALUES (1,'hello');
 	INSERT INTO `t1` VALUES (2,'world');
@@ -243,13 +245,17 @@
 Backups using Drizzledump
 -------------------------
 
-Backups of a database can be made very simply by running the following::
-
-$ drizzledump --all-databases > dumpfile.sql
-
-This can then be re-imported into drizzle at a later date using::
-
-$ drizzle < dumpfile.sql
+Backups of a database can be made very simply by running the following:
+
+.. code-block:: bash
+
+  $ drizzledump --all-databases > dumpfile.sql
+
+This can then be re-imported into drizzle at a later date using:
+
+.. code-block:: bash
+
+  $ drizzle < dumpfile.sql
 
 MySQL Migration using Drizzledump
 ---------------------------------
@@ -268,14 +274,18 @@
    connect to a MySQL server a port (such as 3306) must be specified.
 
 So, simply connecting to a MySQL server with :program:`drizzledump` as follows
-will give you a Drizzle compatible output::
-
-$ drizzledump --all-databases --host=mysql-host --port=3306 --user=mysql-user --password > dumpfile.sql
+will give you a Drizzle compatible output:
+
+.. code-block:: bash
+
+  $ drizzledump --all-databases --host=mysql-host --port=3306 --user=mysql-user --password > dumpfile.sql
 
 Additionally :program:`drizzledump` can now dump from MySQL and import directly
-into a Drizzle server as follows::
-
-$ drizzledump --all-databases --host=mysql-host --port=3306 --user=mysql-user --password --destination-type=database --desination-host=drizzle-host
+into a Drizzle server as follows:
+
+.. code-block:: bash
+
+  $ drizzledump --all-databases --host=mysql-host --port=3306 --user=mysql-user --password --destination-type=database --desination-host=drizzle-host
 
 .. note::
 
@@ -302,15 +312,24 @@
  * mediumblob -> blob
  * longblob -> blob
  * year -> int
- * set -> text
- * date/datetime default 0000-00-00 -> default NULL (Currently, ALL date columns have their DEFAULT set to NULL on migration)
- * date/datetime NOT NULL columns -> NULL
- * any date data containing 0000-00-00 -> NULL
- * time -> int of the number of seconds [1]_
- * enum-> DEFAULT NULL
+ * set -> text [1]_
+ * date/datetime default 0000-00-00 -> default NULL [2]_
+ * date/datetime NOT NULL columns -> NULL [2]_
+ * any date data containing 0000-00-00 -> NULL [2]_
+ * time -> int of the number of seconds [3]_
+ * enum-> DEFAULT NULL [4]_
 
 .. rubric:: Footnotes
 
-.. [1] This prevents data loss since MySQL's TIME data type has a range of
+.. [1] There is currently no good alternative to SET, this is simply to preserve
+       the data in the column.  There is a new alternative to SET to be included
+       at a later date.
+
+.. [2] Currently, ALL date columns have their DEFAULT set to NULL on migration.
+       This is so that any rows with 0000-00-00 dates can convert to NULL.
+
+.. [3] This prevents data loss since MySQL's TIME data type has a range of
        -838:59:59 - 838:59:59, and Drizzle's TIME type has a range of
-       00:00:00 - 23:59:61.999999.
+       00:00:00 - 23:59:59.
+
+.. [4] This is so that empty entries such as '' will convert to NULL.

=== modified file 'docs/clients/errors.rst'
--- docs/clients/errors.rst	2011-02-13 20:50:37 +0000
+++ docs/clients/errors.rst	2011-02-15 22:03:42 +0000
@@ -20,5 +20,5 @@
 
 To resolve this, look for the old-passwords option in your MySQL configuration
 and disable it.  Then update the password for the user you are trying to connect
-with using the 'SET PASSWORD' syntax so that it can be re-recorded in the newer
-password format.
+with using the ``SET PASSWORD`` syntax so that it can be re-recorded in the
+newer password format.

=== modified file 'docs/create_index.rst'
--- docs/create_index.rst	2011-02-13 20:50:37 +0000
+++ docs/create_index.rst	2011-02-15 22:03:42 +0000
@@ -5,7 +5,9 @@
 
 An example:
 
-CREATE INDEX table_1_index ON table_1 (a,b);
+.. code-block:: mysql
+
+   CREATE INDEX table_1_index ON table_1 (a,b);
 
 This would create an index on table_t named  table_1_index that convered
 columns a and b.

=== modified file 'docs/date_time_data_types.rst'
--- docs/date_time_data_types.rst	2011-02-13 20:11:55 +0000
+++ docs/date_time_data_types.rst	2011-02-15 22:03:42 +0000
@@ -6,17 +6,17 @@
 **Date/Time Types**
 
 +------------+------------------------------+------------------------------+------------------------+---------------+---------------+
-|Data Type   |Lowest Value (or NULL)        |Maximum Value                 |Description	            |Storage Size   |Resolution     |
+|Data Type   |Lowest Value (or NULL)        |Maximum Value                 |Description             |Storage Size   |Resolution     |
 +============+==============================+==============================+========================+===============+===============+
 |TIMESTAMP   |'0001-01-01 00:00:00'         |'9999-12-31 23:59:59'         |both date and time      |4 bytes        |1 second       |
 +------------+------------------------------+------------------------------+------------------------+---------------+---------------+
-|TIMESTAMP(6)|'0001-01-01 00:00:00.000000'  |'9999-12-31 23:59:99.999999'  |both date and time      |8 bytes        |1 microsecond  |
+|TIMESTAMP(6)|'0001-01-01 00:00:00.000000'  |'9999-12-31 23:59:59.999999'  |both date and time      |8 bytes        |1 microsecond  |
 +------------+------------------------------+------------------------------+------------------------+---------------+---------------+
 |DATE        |'0001-01-01'                  |'9999-12-31'                  |dates only              |4 bytes        |1 day          |
 +------------+------------------------------+------------------------------+------------------------+---------------+---------------+
-|TIME        |'00:00:00.000000'             |'23:59:99.999999'             |time of day             |8 bytes        |1 microsecond  |
+|TIME        |'00:00:00.000000'             |'23:59:59'                    |time of day             |4 bytes        |1 second       |
 +------------+------------------------------+------------------------------+------------------------+---------------+---------------+
-|DATETIME    |'0001-01-01 00:00:00.000000'  |'9999-12-31 23:59:99.999999'  |both date and time      |8 bytes        |1 microsecond  |
+|DATETIME    |'0001-01-01 00:00:00'         |'9999-12-31 23:59:59'         |both date and time      |4 bytes        |1 second       |
 +------------+------------------------------+------------------------------+------------------------+---------------+---------------+
 
 TIMESTAMP and TIMESTAMP(6)
@@ -26,14 +26,18 @@
 
 To create a TIMESTAMP column that uses microseconds you simply need to specify TIMESTAMP(6) in your table definition. The (6) stands for microsecond granularity (since a microsecond is one millionth of a second). This means that fractional seconds are stored and returned with the field, and it uses 4 more bytes of storage than TIMESTAMP.
 
-For example: ::
+For example:
+
+.. code-block:: mysql
 
 	CREATE TABLE `t1` (
 	`a` INT DEFAULT NULL,
 	`b` TIMESTAMP(6) NULL DEFAULT NULL
 	) ENGINE=InnoDB
 
-You can then use the following (but note that ON DEFAULT/UPDATE CURRENT_TIMESTAMP works with microseconds as well): ::
+You can then use the following (but note that ON DEFAULT/UPDATE CURRENT_TIMESTAMP works with microseconds as well):
+
+.. code-block:: mysql
 
 	insert into t1 values (1, '2010-01-10 07:32:43.234567');
 
@@ -53,7 +57,7 @@
 TIME
 ----
 
-Drizzle's TIME data type has a range of 00:00:00 - 23:59:61.999999, while MySQL's TIME data type has a range of -838:59:59 - 838:59:59.
+Drizzle's TIME data type has a range of 00:00:00 - 23:59:59, while MySQL's TIME data type has a range of -838:59:59 - 838:59:59.
 
 This brings Drizzle closer to the SQL standard. Negative time is not meant to be supported.
 
@@ -64,6 +68,6 @@
 DATETIME
 --------
 
-DATETIME defines a date that is combined with a time of day with fractional seconds, based on 24-hour time. It is similar to TIMESTAMP in that it supports microseconds. 
+DATETIME defines a date that is combined with a time of day, based on 24-hour time. Unlike TIMESTAMP in that it does not support microseconds.
 
 

=== modified file 'docs/delete.rst'
--- docs/delete.rst	2010-12-07 21:20:16 +0000
+++ docs/delete.rst	2011-02-15 22:03:42 +0000
@@ -5,4 +5,6 @@
 
 A typical query might be:
 
-DELETE FROM TABLE_1;
+.. code-block:: mysql
+
+   DELETE FROM TABLE_1;

=== modified file 'docs/distinct.rst'
--- docs/distinct.rst	2011-01-06 02:14:40 +0000
+++ docs/distinct.rst	2011-02-15 22:03:42 +0000
@@ -5,7 +5,9 @@
 
 Sometimes it's helpful to list only the different, distinct values in a table; in this case the DISTINCT keyword can be used.
 
-SQL SELECT DISTINCT Syntax: ::
+SQL SELECT DISTINCT Syntax: 
+
+.. code-block:: mysql
 
 	SELECT DISTINCT column_name(s)
 	FROM table_name
@@ -24,7 +26,9 @@
 | 3 	  | Peterson   | Kari 	  |30 Mell   | Reno   |
 +---------+------------+----------+----------+--------+
 
-In order to select distinct values from the column named "City" from the table above, use the following SELECT statement: ::
+In order to select distinct values from the column named "City" from the table above, use the following SELECT statement:
+
+.. code-block:: mysql
 
 	SELECT DISTINCT City FROM Persons;
 

=== modified file 'docs/dynamic.rst'
--- docs/dynamic.rst	2011-02-13 20:50:37 +0000
+++ docs/dynamic.rst	2011-02-15 22:03:42 +0000
@@ -6,12 +6,16 @@
 Dynamic SQL allows you to execute DDL statements (and other SQL statements) that are not supported in purely static SQL programs.
 
 In Drizzle you can use the EXECUTE command along with :doc:'user defined variables <variables>'
-to create SQL in a dynamic manner on the server. An exmaple of this is: ::
+to create SQL in a dynamic manner on the server. An exmaple of this is:
+
+.. code-block:: mysql
 
 	SET @var= "SELECT 1";
 	EXECUTE @var;
 
-You can also omit the variable and just insert the SQL directly: ::
+You can also omit the variable and just insert the SQL directly:
+
+.. code-block:: mysql
 
 	EXECUTE "SELECT 1";
 
@@ -19,7 +23,9 @@
 generated and no data will be returned by the execution of the statement.
 
 If you want to launch the query in a separate session, you can do that with
-the following: ::
+the following:
+
+.. code-block:: mysql
 
 	EXECUTE "SELECT 1" CONCURRENT;
 

=== modified file 'docs/functions/aggregatefunctions.rst'
--- docs/functions/aggregatefunctions.rst	2011-01-22 20:34:44 +0000
+++ docs/functions/aggregatefunctions.rst	2011-02-15 22:03:42 +0000
@@ -3,12 +3,14 @@
 
 SQL group (aggregate) functions operate on sets of values. If you use an aggregate function in a statement containing no GROUP BY clause, it is equivalent to grouping on all rows.
 
-General syntax for aggregate functions is: ::
+General syntax for aggregate functions is:
+
+.. code-block:: mysql
 
 	SELECT "function type" ("column_name")
 	FROM "table_name";
-
-The following are examples of aggregate functions:
+
+The following are examples of aggregate functions:
 
 **AVG**:  Return the average value of the argument. (Does not work with temporal values unless first converted to numeric values.)
 

=== modified file 'docs/functions/count.rst'
--- docs/functions/count.rst	2011-01-22 20:34:44 +0000
+++ docs/functions/count.rst	2011-02-15 22:03:42 +0000
@@ -19,13 +19,17 @@
 |6       |10/2/2010          |820	  |4	           |Smith              |
 +--------+-------------------+------------+----------------+-------------------+
 
-The SQL COUNT function returns the number of rows in a table satisfying the criteria specified in the WHERE clause. If we want to count how many orders has made a customer with CustomerName of Smith, we will use the following SQL COUNT expression: ::
+The SQL COUNT function returns the number of rows in a table satisfying the criteria specified in the WHERE clause. If we want to count how many orders has made a customer with CustomerName of Smith, we will use the following SQL COUNT expression:
+
+.. code-block:: mysql
 
 	SELECT COUNT * FROM Nodes
 	WHERE UserName = "Smith";
 
 In the above statement, the COUNT keyword returns the number 3, because the user Smith has 3 total nodes.
 
-If you don’t specify a WHERE clause when using the COUNT keyword, your statement will simply return the total number of rows in the table, which would be 6 in this example: ::
+If you don’t specify a WHERE clause when using the COUNT keyword, your statement will simply return the total number of rows in the table, which would be 6 in this example:
+
+.. code-block:: mysql
 
 	SELECT COUNT * FROM Nodes;

=== modified file 'docs/functions/extract_date.rst'
--- docs/functions/extract_date.rst	2011-01-25 00:21:20 +0000
+++ docs/functions/extract_date.rst	2011-02-15 22:03:42 +0000
@@ -13,7 +13,9 @@
 
 The following field names are available:
 
-**day** ::
+**day**
+
+.. code-block:: mysql
 	
 	SELECT EXTRACT(DAY FROM TIMESTAMP '2001-02-16 20:38:40');
 
@@ -21,7 +23,9 @@
 
 *Result: 16*
 
-**decade** ::
+**decade**
+
+.. code-block:: mysql
 	
 	SELECT EXTRACT(DECADE FROM TIMESTAMP '2001-02-16 20:38:40');
 
@@ -29,7 +33,9 @@
 
 *Result: 200*
 
-**dow** ::
+**dow**
+
+.. code-block:: mysql
 	
 	SELECT EXTRACT(DOW FROM TIMESTAMP '2001-02-16 20:38:40');
 
@@ -37,7 +43,9 @@
 
 *Result: 5*
 
-**doy** ::
+**doy**
+
+.. code-block:: mysql
 
 	SELECT EXTRACT(DOY FROM TIMESTAMP '2001-02-16 20:38:40');
 
@@ -45,7 +53,9 @@
 
 *Result: 47*
 
-**hour** ::
+**hour**
+
+.. code-block:: mysql
 
 	SELECT EXTRACT(HOUR FROM TIMESTAMP '2001-02-16 20:38:40');
 
@@ -53,7 +63,9 @@
 
 *Result: 20*
 
-**microseconds** ::
+**microseconds**
+
+.. code-block:: mysql
 
 	SELECT EXTRACT(MICROSECONDS FROM TIME '17:12:28.5');
 
@@ -61,7 +73,9 @@
 
 *Result: 28500000*
 
-**minute** ::
+**minute**
+
+.. code-block:: mysql
 
 	SELECT EXTRACT(MINUTE FROM TIMESTAMP '2001-02-16 20:38:40');
 
@@ -72,21 +86,29 @@
 **month**
 
 For timestamp values, the number of the month within the year (1 - 12). 
-For interval values, the number of months (0 - 11). ::
+For interval values, the number of months (0 - 11).
+
+.. code-block:: mysql
 
 	SELECT EXTRACT(MONTH FROM TIMESTAMP '2010-12-29 08:45:27');
 
-*Result: 12* ::
+*Result: 12*
+
+.. code-block:: mysql
 
 	SELECT EXTRACT(MONTH FROM INTERVAL '3 years 4 months');
 
-*Result: 4* ::
+*Result: 4*
+
+.. code-block:: mysql
 
 	SELECT EXTRACT(MONTH FROM INTERVAL '3 years 13 months');
 
 *Result: 1*
 
-**quarter** ::
+**quarter**
+
+.. code-block:: mysql
 
 	SELECT EXTRACT(QUARTER FROM TIMESTAMP '2010-12-29 08:45:27');
 
@@ -94,13 +116,17 @@
 	
 *Result: 4*
 
-**second** ::
+**second**
+
+.. code-block:: mysql
 
 	SELECT EXTRACT(SECOND FROM TIMESTAMP '2010-12-29 08:45:27');
 
 The seconds field, including fractional parts (0 - 59)
 	
-*Result: 27* ::
+*Result: 27*
+
+.. code-block:: mysql
 
 	SELECT EXTRACT(SECOND FROM TIME '08:15:22.5');
 
@@ -116,23 +142,31 @@
 
 ISO 8601:1988 means that if the week containing January 1 has four or more days in the new year, then it is week 1; otherwise it is the last week of the previous year, and the next week is week 1. The ISO-8601 week starts on Monday.
 
-It's possible for early January dates to be part of the 52nd or 53rd week of the previous year. For example, 2011-01-01 was part of the 52nd week of year 2010. ::
+It's possible for early January dates to be part of the 52nd or 53rd week of the previous year. For example, 2011-01-01 was part of the 52nd week of year 2010.
+
+.. code-block:: mysql
 
 	SELECT EXTRACT(WEEK FROM TIMESTAMP '2010-01-25 12:44:06');
 
 *Result: 4*
 
-**year** ::
+**year**
+
+.. code-block:: mysql
 
 	SELECT EXTRACT(YEAR FROM TIMESTAMP '2009-02-16 20:38:40');
 
 *Result: 2009*
 
-The valid field names for date_part are the same as for extract. ::
+The valid field names for date_part are the same as for extract.
+
+.. code-block:: mysql
 
 	SELECT date_part('day', TIMESTAMP '2010-07-16 10:12:05');
 
-*Result: 16* ::
+*Result: 16*
+
+.. code-block:: mysql
 
 	SELECT date_part('hour', INTERVAL '5 hours 12 minutes');
 

=== modified file 'docs/functions/scalarfunctions.rst'
--- docs/functions/scalarfunctions.rst	2011-01-22 20:34:44 +0000
+++ docs/functions/scalarfunctions.rst	2011-02-15 22:03:42 +0000
@@ -3,7 +3,9 @@
 
 *SQL scalar functions are based on the input value, and return a single value.*
 
-General syntax for scalar functions is: ::
+General syntax for scalar functions is:
+
+.. code-block:: mysql
 
 	SELECT "function type" ("column_name")
 	FROM "table_name"

=== modified file 'docs/groupby.rst'
--- docs/groupby.rst	2011-01-14 05:18:39 +0000
+++ docs/groupby.rst	2011-02-15 22:03:42 +0000
@@ -3,7 +3,9 @@
 
 The GROUP BY clause is used to extract only those records that fulfill a specified criterion.
 
-SQL GROUP BY Syntax ::
+SQL GROUP BY Syntax
+
+.. code-block:: mysql
 
 	SELECT column_name, aggregate_function(column_name)
 	FROM table_name
@@ -30,7 +32,9 @@
 | 6       |2011-01-03    | Food         |20           |175       |
 +---------+--------------+--------------+-------------+----------+
 
-Running the following simple query::
+Running the following simple query
+
+.. code-block:: mysql
 
 	SELECT userID
 	FROM activities
@@ -54,7 +58,9 @@
 
 However, GROUP BY is much more powerful when used with an aggregate function. Let's say you want to find the total amount spent by each unique User.
 
-You could use the following SQL statement: ::
+You could use the following SQL statement:
+
+.. code-block:: mysql
 
 	SELECT userID,SUM(ActivityCost) AS "Activity Total"
 	FROM Activities
@@ -73,7 +79,9 @@
 
 With the aggregate SUM() function, SQL can calculate how much each unique user has spent on activities over time.
 
-We can also use the GROUP BY statement on more than one column, like this: ::
+We can also use the GROUP BY statement on more than one column, like this:
+
+.. code-block:: mysql
 
 	SELECT userID,ActivityDate,SUM(ActivityCost)
 	FROM Activities

=== modified file 'docs/having.rst'
--- docs/having.rst	2011-01-14 05:18:23 +0000
+++ docs/having.rst	2011-02-15 22:03:42 +0000
@@ -3,7 +3,9 @@
 
 The WHERE keyword cannot be used with aggregate functions, but the HAVING clause can be; this is its primary use.
 
-SQL HAVING Syntax: ::
+SQL HAVING Syntax:
+
+.. code-block:: mysql
 
 	SELECT column_name, aggregate_function(column_name)
 	FROM table_name
@@ -31,7 +33,9 @@
 | 6       |2011-01-03    | Food         |20           |175       |
 +---------+--------------+--------------+-------------+----------+
 
-In order to find if any users have spent more than $100 on recreational activities, use the following SQL statement: ::
+In order to find if any users have spent more than $100 on recreational activities, use the following SQL statement:
+
+.. code-block:: mysql
 
 	SELECT userID,SUM(ActivityCost) FROM Activities
 	GROUP BY userID
@@ -47,7 +51,9 @@
 
 Now we want to find if userIDs "131", "256", or "175" spent less than $50 on Activities.
 
-We add an ordinary WHERE clause to the SQL statement: ::
+We add an ordinary WHERE clause to the SQL statement:
+
+.. code-block:: mysql
 
 	SELECT userID,SUM(ActivityCost) FROM Activities
 	WHERE userID='131' OR userID='256' OR userID="175"

=== modified file 'docs/insert.rst'
--- docs/insert.rst	2011-02-13 20:50:37 +0000
+++ docs/insert.rst	2011-02-15 22:03:42 +0000
@@ -5,7 +5,9 @@
 
 A type query:
 
-INSERT INTO A VALUES ("1");
+.. code-block:: mysql
+
+   INSERT INTO A VALUES ("1");
 
 
 .. todo::

=== modified file 'docs/installing/from_source.rst'
--- docs/installing/from_source.rst	2011-01-24 09:14:25 +0000
+++ docs/installing/from_source.rst	2011-02-15 22:03:42 +0000
@@ -54,13 +54,17 @@
 --------------------
 The latest source release can always be found on our `LaunchPad site
 <https://launchpad.net/drizzle>`_, alternatively the bzr source from our stable
-trunk can be obtained by doing::
+trunk can be obtained by doing:
+
+.. code-block:: bash
 
    bzr branch lp:drizzle
 
 Compiling The Source
 --------------------
-Compiling is as simple as doing the following inside the source::
+Compiling is as simple as doing the following inside the source:
+
+.. code-block:: bash
 
    ./config/autorun.sh
    ./configure

=== modified file 'docs/installing/redhat.rst'
--- docs/installing/redhat.rst	2011-02-13 20:50:37 +0000
+++ docs/installing/redhat.rst	2011-02-15 22:03:42 +0000
@@ -11,13 +11,17 @@
 `EPEL <http://fedoraproject.org/wiki/EPEL>`_ repository is also added to your
 distribution.
 
-To add that repository, run the following command::
+To add that repository, run the following command:
+
+.. code-block:: bash
 
   sudo rpm -Uvh http://download.fedora.redhat.com/pub/epel/5/i386/epel-release-5-4.noarch.rpm
 
 To add the repository to your distribution you also need to create a /etc/yum.repos.d/drizzle.repo file with the following content:
 
-*RedHat*::
+*RedHat*
+
+.. code-block:: ini
 
    [drizzle]
    name=drizzle
@@ -31,7 +35,9 @@
    enabled=1
    gpgcheck=0
 
-*Fedora*::
+*Fedora*
+
+.. code-block:: ini
 
    [drizzle]
    name=drizzle
@@ -45,7 +51,9 @@
    enabled=1
    gpgcheck=0
 
-You can then use the following shell command::
+You can then use the following shell command:
+
+.. code-block:: bash
 
    yum install drizzle7
 

=== modified file 'docs/orderby.rst'
--- docs/orderby.rst	2011-02-13 20:50:37 +0000
+++ docs/orderby.rst	2011-02-15 22:03:42 +0000
@@ -3,7 +3,9 @@
 
 The ORDER BY keyword is used to sort the result-set by column; by default, it sorts the records in ascending order.
 
-SQL ORDER BY Syntax: ::
+SQL ORDER BY Syntax:
+
+.. code-block:: mysql
 
 	SELECT column_name(s)
 	FROM table_name
@@ -23,7 +25,9 @@
 | 3 	  | Peterson   | Kari 	  |30 Mell   | Reno   |
 +---------+------------+----------+----------+--------+
 
-To select all the persons from the table above, and also sort them by their last name, use the following SELECT statement: ::
+To select all the persons from the table above, and also sort them by their last name, use the following SELECT statement:
+
+.. code-block:: mysql
 
 	SELECT * FROM Persons
 	ORDER BY LastName;
@@ -40,7 +44,9 @@
 | 2 	  | Roberts    | Teri 	  |21 Brown  | Chicago|
 +---------+------------+----------+----------+--------+
 
-ORDER BY DESC can be used to reverse the order of the result set. ::
+ORDER BY DESC can be used to reverse the order of the result set.
+
+.. code-block:: mysql
 
 	SELECT * FROM Persons
 	ORDER BY LastName DESC;

=== modified file 'docs/queries.rst'
--- docs/queries.rst	2011-01-14 05:14:31 +0000
+++ docs/queries.rst	2011-02-15 22:03:42 +0000
@@ -6,7 +6,9 @@
 persistent effects on the database. SELECT simply retrieves data from
 one or more tables, or expressions.
 
-A query includes a list of columns to be included in a result set; an example of this would be:  ::
+A query includes a list of columns to be included in a result set; an example of this would be:
+
+.. code-block:: mysql
 
 	SELECT * FROM table_name;
 
@@ -24,7 +26,9 @@
    orderby
    join
 
-For example, ::
+For example:
+
+.. code-block:: mysql
 
 	SELECT first_column_name, second_column_name
 	FROM table_name

=== modified file 'docs/replace.rst'
--- docs/replace.rst	2011-01-14 05:13:52 +0000
+++ docs/replace.rst	2011-02-15 22:03:42 +0000
@@ -8,11 +8,15 @@
 
 A typical query:
 
-REPLACE INTO table_1 SET a=5;
+.. code-block:: mysql
+
+   REPLACE INTO table_1 SET a=5;
 
 or
 
-REPLACE INTO table_1 VALUES (4);
+.. code-block:: mysql
+
+   REPLACE INTO table_1 VALUES (4);
 
 
 REPLACE is an extension to the SQL Standard that first appeared in MySQL.

=== modified file 'docs/replication.rst'
--- docs/replication.rst	2011-01-14 05:13:33 +0000
+++ docs/replication.rst	2011-02-15 22:03:42 +0000
@@ -24,7 +24,9 @@
     default global value is FALSE which will not include the query in the
     messages. It can be controlled per session, as well. For example:
 
-    ``drizzle> set @@replicate_query = 1;``
+    .. code-block:: mysql
+
+       drizzle> set @@replicate_query = 1;
 
     The stored query should be used as a guide only, and never executed
     on a slave to perform replication as this will lead to incorrect results.
@@ -164,7 +166,9 @@
 It's easiest to understand this mechanism by following through a real-world
 scenario.
 
-Suppose the following table::
+Suppose the following table:
+
+.. code-block:: mysql
 
   CREATE TABLE test.person
   (
@@ -176,7 +180,9 @@
 
 Also suppose that test.t1 contains 1 million records.
 
-Next, suppose a client issues the SQL statement::
+Next, suppose a client issues the SQL statement:
+
+.. code-block:: mysql
 
   UPDATE test.person SET is_active = 'N';
 

=== modified file 'docs/savepoints.rst'
--- docs/savepoints.rst	2011-01-14 05:13:18 +0000
+++ docs/savepoints.rst	2011-02-15 22:03:42 +0000
@@ -7,6 +7,8 @@
 
 This sets a savepoint that can be returned to in the current transaction. The "identifier" is the name given to the new savepoint. If the identifier has already been used then the original identifier is replaced. Example:
 
+.. code-block:: mysql
+
      SAVEPOINT A;
      INSERT INTO t1 values (1);
      SAVEPOINT A;

=== modified file 'docs/truncate.rst'
--- docs/truncate.rst	2011-02-13 20:50:37 +0000
+++ docs/truncate.rst	2011-02-15 22:03:42 +0000
@@ -5,8 +5,9 @@
 
    I don't think the below SERIAL/AUTO_INCREMENT thing below is true.
 
-This will delete all data in a table but unlike a DROP TABLE it will allow you to keep the table in your database. It deletes the rows but leaves all counters, such as a SERIAL, in place. ::
+This will delete all data in a table but unlike a DROP TABLE it will allow you to keep the table in your database. It deletes the rows but leaves all counters, such as a SERIAL, in place.
 
+.. code-block:: mysql
 
 	TRUNCATE TABLE table_name
 

=== modified file 'docs/update.rst'
--- docs/update.rst	2011-01-17 17:18:16 +0000
+++ docs/update.rst	2011-02-15 22:03:42 +0000
@@ -5,12 +5,16 @@
 
 A type query:
 
-UPDATE TABLE_1 SET a="1" WHERE <condition>;
+.. code-block:: mysql
+
+   UPDATE TABLE_1 SET a="1" WHERE <condition>;
 
 Multi-table delete and multi-table update code was removed from Drizzle.
 
-Multi-update/delete can be accomplished through subqueries. For example: ::
+Multi-update/delete can be accomplished through subqueries. For example:
+
+.. code-block:: mysql
 
 	UPDATE tableX SET tableXfield = (SELECT MAX(tableY.tableYfield) FROM tableY WHERE tableX.tableXfield = tableY.tableYfield)
 
-In other database frameworks, multi-update and multi-delete are used to change information in *one* table, but the rows to change are determined by using more than one table. In that case, subqueries work to address the issue of changing information in one table based on information in more than one table.
\ No newline at end of file
+In other database frameworks, multi-update and multi-delete are used to change information in *one* table, but the rows to change are determined by using more than one table. In that case, subqueries work to address the issue of changing information in one table based on information in more than one table.

=== modified file 'docs/where.rst'
--- docs/where.rst	2011-01-14 05:08:42 +0000
+++ docs/where.rst	2011-02-15 22:03:42 +0000
@@ -3,7 +3,9 @@
 
 The WHERE clause is used to extract only those records that fulfill a specified criterion.
 
-Simple SQL WHERE Syntax ::
+Simple SQL WHERE Syntax:
+
+.. code-block:: mysql
 
 	SELECT column_name(s)
 	FROM table_name
@@ -23,7 +25,9 @@
 | 3 	  | Peterson   | Kari 	  |30 Mell   | Reno   |
 +---------+------------+----------+----------+--------+
  
-If you want to select only the persons living in the city "Chicago" from the table above, use the following SELECT statement: ::
+If you want to select only the persons living in the city "Chicago" from the table above, use the following SELECT statement:
+
+.. code-block:: mysql
 
 	SELECT * FROM Persons
 	WHERE City='Chicago'
@@ -32,7 +36,7 @@
 
 +---------+------------+----------+----------+--------+
 | Id 	  |LastName    |FirstName |Address   |City    |
-+---------+------------+----------+----------+--------+
++=========+============+==========+==========+========+
 |1 	  | Larson     | Sue 	  |3 Cherry  | Chicago|
 +---------+------------+----------+----------+--------+
 |2 	  | Roberts    | Teri 	  |21 Brown  | Chicago|

